﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using Sailboat.Entities;

namespace Sailboat.DrawingObjects
{
    public static class ExtentionDrawingBoat
    {
        /// <summary>
        /// Создание объекта из строки
        /// </summary>
        /// <param name="info">Строка с данными для создания объекта</param>
        /// <param name="separatorForObject">Разделитель даннных</param>
        /// <param name="width">Ширина</param>
        /// <param name="height">Высота</param>
        /// <returns>Объект</returns>
        public static DrawingBoat? CreateDrawingBoat(this string info, char separatorForObject, int width, int height)
        {
            string[] strs = info.Split(separatorForObject);
            if (strs.Length == 3)
            {
                return new DrawingBoat(Convert.ToInt32(strs[0]),
                Convert.ToInt32(strs[1]), Color.FromName(strs[2]), width, height);
            }
            if (strs.Length == 6)
            {
                return new DrawingSailboat(Convert.ToInt32(strs[0]),
                Convert.ToInt32(strs[1]),
                Color.FromName(strs[2]),
                Color.FromName(strs[3]),
                Convert.ToBoolean(strs[4]),
                Convert.ToBoolean(strs[5]), 
                width, height);
            }
            return null;
        }
        /// <summary>
        /// Получение данных для сохранения в файл
        /// </summary>
        /// <param name="drawningCar">Сохраняемый объект</param>
        /// <param name="separatorForObject">Разделитель даннных</param>
        /// <returns>Строка с данными по объекту</returns>
        public static string GetDataForSave(this DrawingBoat drawingBoat, char separatorForObject)
        {
            var boat = drawingBoat.EntityBoat;
            if (boat == null)
            {
                return string.Empty;
            }

            var str = $"{boat.Speed}{separatorForObject}{boat.Weight}{separatorForObject}{boat.BodyColor.Name}";

            if (boat is not EntitySailboat sailboat)
            {
                return str;
            }
            return $"{str}{separatorForObject}{sailboat.AdditionalColor.Name}{separatorForObject}{sailboat.Hull}{separatorForObject}{sailboat.Sail}";
        }
    }
}
